@@ -82,9 +82,19 @@ class Domoticz(IPlugin):
 				log.msg("BODIES  :  %s" % (bodies))
 				log.msg("local  :  %s" % (local))
 				log.msg("number  :  %s" % (int(rs['idx'])))
+#periph action
+##http://192.168.0.1:8080/json.htm?type=command&param=switchlight&idx=39&switchcmd=On&level=0
+#Panel security
+##http://192.168.0.1:8080/json.htm?type=command&param=setsecstatus&secstatus=0&seccode=1234
+#Sensor action
+##http://192.168.0.1:8080/json.htm?type=devices&filter=temp&used=true&order=Name
+###température 	/ consommation / état batterie / Humidity 
+#0scenario action 
+##http://192.168.0.1:8080/json.htm?type=command&param=switchscene&idx=1&switchcmd=On
+#				
 		#		resp = requests.get ('http://192.168.0.3:8080/json.htm?type=command&param=switchlight&idx=%s&switchcmd=%s&level=0' % (rs['idx'],on_off.capitalize()))
+				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=devices&filter=temp&used=true&order=Name')
 #				log.msg("resp  :  %s" % (req))				
-#				resp = requests.get (req)
 				log.msg("resp  :  %s" % (resp))
 		if bodies == "":
 			bodies = "j'ai rien compris aux devices"
